| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.GstAudio.Objects.AudioAggregatorConvertPad
Description
An implementation of GstPad that can be used with AudioAggregator.
See AudioAggregator for more details.
Synopsis
- newtype AudioAggregatorConvertPad = AudioAggregatorConvertPad (ManagedPtr AudioAggregatorConvertPad)
- class (GObject o, IsDescendantOf AudioAggregatorConvertPad o) => IsAudioAggregatorConvertPad o
- toAudioAggregatorConvertPad :: (MonadIO m, IsAudioAggregatorConvertPad o) => o -> m AudioAggregatorConvertPad
- noAudioAggregatorConvertPad :: Maybe AudioAggregatorConvertPad
- clearAudioAggregatorConvertPadConverterConfig :: (MonadIO m, IsAudioAggregatorConvertPad o) => o -> m ()
- constructAudioAggregatorConvertPadConverterConfig :: IsAudioAggregatorConvertPad o => Structure -> IO (GValueConstruct o)
- getAudioAggregatorConvertPadConverterConfig :: (MonadIO m, IsAudioAggregatorConvertPad o) => o -> m (Maybe Structure)
- setAudioAggregatorConvertPadConverterConfig :: (MonadIO m, IsAudioAggregatorConvertPad o) => o -> Structure -> m ()
Exported types
newtype AudioAggregatorConvertPad Source #
Memory-managed wrapper type.
Constructors
| AudioAggregatorConvertPad (ManagedPtr AudioAggregatorConvertPad) |
Instances
| Eq AudioAggregatorConvertPad Source # | |
Defined in GI.GstAudio.Objects.AudioAggregatorConvertPad Methods (==) :: AudioAggregatorConvertPad -> AudioAggregatorConvertPad -> Bool # (/=) :: AudioAggregatorConvertPad -> AudioAggregatorConvertPad -> Bool # | |
| GObject AudioAggregatorConvertPad Source # | |
Defined in GI.GstAudio.Objects.AudioAggregatorConvertPad Methods gobjectType :: IO GType # | |
| IsGValue AudioAggregatorConvertPad Source # | Convert |
Defined in GI.GstAudio.Objects.AudioAggregatorConvertPad Methods | |
| HasParentTypes AudioAggregatorConvertPad Source # | |
| type ParentTypes AudioAggregatorConvertPad Source # | |
Defined in GI.GstAudio.Objects.AudioAggregatorConvertPad type ParentTypes AudioAggregatorConvertPad = '[AudioAggregatorPad, AggregatorPad, Pad, Object, Object] | |
class (GObject o, IsDescendantOf AudioAggregatorConvertPad o) => IsAudioAggregatorConvertPad o Source #
Type class for types which can be safely cast to AudioAggregatorConvertPad, for instance with toAudioAggregatorConvertPad.
Instances
toAudioAggregatorConvertPad :: (MonadIO m, IsAudioAggregatorConvertPad o) => o -> m AudioAggregatorConvertPad Source #
Cast to AudioAggregatorConvertPad, for types for which this is known to be safe. For general casts, use castTo.
noAudioAggregatorConvertPad :: Maybe AudioAggregatorConvertPad Source #
A convenience alias for Nothing :: Maybe AudioAggregatorConvertPad.
Methods
Overloaded methods
Properties
converterConfig
No description available in the introspection data.
clearAudioAggregatorConvertPadConverterConfig :: (MonadIO m, IsAudioAggregatorConvertPad o) => o -> m () Source #
Set the value of the “converter-config” property to Nothing.
When overloading is enabled, this is equivalent to
clear #converterConfig
constructAudioAggregatorConvertPadConverterConfig :: IsAudioAggregatorConvertPad o => Structure -> IO (GValueConstruct o) Source #
Construct a GValueConstruct with valid value for the “converter-config” property. This is rarely needed directly, but it is used by new.
getAudioAggregatorConvertPadConverterConfig :: (MonadIO m, IsAudioAggregatorConvertPad o) => o -> m (Maybe Structure) Source #
Get the value of the “converter-config” property.
When overloading is enabled, this is equivalent to
get audioAggregatorConvertPad #converterConfig
setAudioAggregatorConvertPadConverterConfig :: (MonadIO m, IsAudioAggregatorConvertPad o) => o -> Structure -> m () Source #
Set the value of the “converter-config” property.
When overloading is enabled, this is equivalent to
setaudioAggregatorConvertPad [ #converterConfig:=value ]